spannertools.BeamSpanner
========================

.. abjad-lineage:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner

.. autoclass:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.append
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.append_left
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.attach
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.components
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.detach
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.direction
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.extend
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.extend_left
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.fracture
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.fuse
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.get_duration
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.get_timespan
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.index
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.is_beamable_component
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.leaves
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.override
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.pop
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.pop_left
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.set
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__call__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__contains__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__copy__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__eq__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__getitem__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__len__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__lt__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__ne__
      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__repr__

Bases
-----

- :py:class:`spannertools.DirectedSpanner <abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.is_beamable_component
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner.__repr__
   :noindex:
